import { 
  event,
  json,
  hierarchy,
  linkHorizontal,
  select,
  tree,
  zoom
} from 'd3';

const width = +document.body.clientWidth,
			height = +document.body.clientHeight,
			margin = {top: 20, right: 100, bottom: 20, left: 80},
      innerWidth = width - margin.left - margin.right
			innerHeight = height - margin.top - margin.bottom;


const svg = select('svg');
const treeLayout = tree().size([innerHeight, innerWidth]);

const zoomG = svg
      .attr('width', width)
      .attr('height', height)
		.append('g')

const g = zoomG.append('g')
			.attr('transform', `translate(${margin.left}, ${margin.top})`);

svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform)
}))


json('data.json').then((data) => {
  
  const root = hierarchy(data)
  	.sort((a, b) => 
    	(a.height - b.height) || a.data.data.id.localeCompare(b.data.data.id)
		);
  const links = treeLayout(root).links();
  
  const linkPathGenerator = linkHorizontal()
  	.x(d => d.y)
  	.y(d => d.x);
  
  g.selectAll('.link').data(links)
  	.enter().append('path')
  		.attr('class', 'link')
  		.attr('d', linkPathGenerator);
  
  g.selectAll('.label').data(root.descendants())
  	.enter().append('text')
  		.attr('class', 'label')
  		.attr('x', d => d.y)
  		.attr('y', d => d.x)
  		.attr('dy', '0.32em')
  		.attr('text-anchor', d => d.children  ? 'middle' : 'start')
  		.attr('font-size', d => 3.2 - d.depth + 'em')
  		.text(d => d.data.data.id)
});